@@ -38,6 +38,10 @@
 #include "girl-listener.h"
 #include "girl-station.h"
 #include "girl-program.h"
+#include "girl-player-frontend.h"
+#include "girl-player-backend.h"
+#include "girl-record-frontend.h"
+#include "girl-record-backend.h"
 
 GirlData *girl;
 
@@ -69,10 +73,22 @@ int main(int argc, char *argv[])
 #endif
 
 	if (gnome_vfs_init() == FALSE) {
-		g_warning(_("GNOME VFS initialization failed!\n"));
+	        GIRL_DEBUG_MSG(_("GNOME VFS initialization failed!\n"));
 		exit(1);
 	}
 
+	if (!girl_player_frontend_init (&argc, &argv)) {
+		GIRL_DEBUG_MSG (_("Player Frontend initialization failure..."));
+		exit (0);
+	}
+
+	if (!girl_player_backend_init (&argc, &argv)) {
+		GIRL_DEBUG_MSG (_("Player Backend creation failure"));
+		exit (0);
+	}
+
+	gst_init(&argc, &argv);
+
 	gnome_program_init(PACKAGE, VERSION,
 			   LIBGNOMEUI_MODULE,
 			   argc, argv,
@@ -165,6 +181,7 @@ static void cause_movement(int way)
 void on_previous_station_click(GtkWidget * a, gpointer user_data)
 {
 	GirlStationInfo *station = (GirlStationInfo *)girl->previous_station;
+
 	girl->previous_station = girl->selected_station;
 
 	if (station != NULL) {
@@ -215,6 +232,7 @@ void on_previous_station_click(GtkWidget * a, gpointer user_data)
 void on_next_station_click(GtkWidget * a, gpointer user_data)
 {
 	GList *l = g_list_first(girl_stations);
+	girl_player_frontend_stop (girl->player_window, NULL);
 	girl->previous_station = (GirlStationInfo*)girl->selected_station;
 	if (l != NULL) {
 		GirlStationInfo *station = l->data;
@@ -464,6 +482,7 @@ void on_stations_selector_changed(GtkWidget * a, gpointer user_data)
 
 	station->name = g_strdup(g_object_get_data(G_OBJECT(a), "station_name"));
 	/* girl_history = g_list_add(GLIST(girl_history), (GirlStationInfo *)station); */
+	girl_player_frontend_stop(girl->player_window, NULL);
 	girl_helper_run(girl->selected_station_uri,
 			girl->selected_station_name,
 			GIRL_STREAM_SHOUTCAST,
@@ -613,16 +632,37 @@ void quit_app(GtkWidget * a, gpointer user_data)
 	}
 	// stationinfo = l->data;
 	// girl_station_save(stationinfo, NULL, NULL, NULL, NULL, NULL, NULL);
+
 	g_spawn_close_pid(girl->record_pid);
 	g_spawn_close_pid(girl->player_pid);
 
+
 	g_subprocess_force_exit(girl->player_subprocess);
 	g_subprocess_force_exit(girl->record_subprocess);
 	// kill(girl->record_pid,SIGHUP);
 	// kill(girl->player_pid,SIGHUP);
+
+	gtk_widget_destroy(girl->player_window);
+	gtk_widget_destroy(girl->record_window);
+
+	girl_player_backend_stop();
+	girl_record_backend_stop();
+
 	gtk_main_quit();
 }
 
+void about_rec(GtkWidget * a, gpointer user_data)
+{
+	static GtkWindow *about = NULL;
+	about = GTK_WINDOW(gtk_message_dialog_new(GTK_WINDOW(girl_app),
+				       GTK_DIALOG_DESTROY_WITH_PARENT,
+				       GTK_MESSAGE_QUESTION,
+				       GTK_BUTTONS_YES_NO,
+						  "Recording is not yet implemented.  If you want to implement it, see src/girl-record.c and send an email to ole@src.gnome.org with the patch."));
+
+	gtk_dialog_run(GTK_DIALOG(about));
+}
+
 void about_app(GtkWidget * a, gpointer user_data)
 {
 	static GtkWindow *about = NULL;
@@ -663,7 +703,7 @@ void about_app(GtkWidget * a, gpointer user_data)
 			     NULL };
 	gchar* comments = { _("Locate Internet Radio Stations") };
 	gchar* copyright = { _("Copyright (C) 2014, 2015, 2016  Ole Aamot Software") };
-	gchar* documenters[] = { _("Mario Blättermann <mario.blaettermann@gmail.com> (German translation)"), _("Marek Černocký <marek@manet.cz> (Czech translation)"), _("Daniel Mustieles <daniel.mustieles@gmail.com> (Spanish translation)"), NULL };
+	gchar* documenters[] = { _("Mario Blättermann <mario.blaettermann@gmail.com> (German translation)"), _("Marek Černocký <marek@manet.cz> (Czech translation)"), _("Daniel Mustieles <daniel.mustieles@gmail.com> (Spanish translation)"), _("Josef Andersson <josef.andersson@fripost.org> (Swedish translation)"), NULL };
 
 	static GdkPixbuf* logo;
 
@@ -859,13 +899,21 @@ void on_record_button_clicked(GtkWidget *a, gpointer user_data)
 	GCredentials *credentials;
 	GError **err = NULL;
 
-	credentials = g_credentials_new ();
+	dialog = gtk_message_dialog_new(GTK_WINDOW(girl_app),
+					GTK_DIALOG_MODAL,
+					GTK_MESSAGE_ERROR,
+					GTK_BUTTONS_CLOSE,
+					"Recording is not yet implemented.  If you want to implement it, see src/girl-record.c and send an email to ole@src.gnome.org with the patch.");
+	gtk_dialog_run(GTK_DIALOG(dialog));
+	gtk_widget_destroy(dialog);
 	
+	credentials = g_credentials_new ();
+
 	if (girl->selected_station_name != NULL) {
-		girl_helper_run(girl->selected_station_uri,
-				girl->selected_station_name,
-				GIRL_STREAM_SHOUTCAST,
-				GIRL_STREAM_RECORD);
+		/* girl_helper_run(girl->selected_station_uri, */
+		/* 		girl->selected_station_name, */
+		/* 		GIRL_STREAM_SHOUTCAST, */
+		/* 		GIRL_STREAM_RECORD); */
 		girl->selected_runners = girl_runners_new(g_credentials_get_unix_pid(credentials, err),
 							  girl->selected_station_name,
 							  "date",
@@ -902,17 +950,18 @@ void on_stop_button_clicked(GtkWidget *a, gpointer user_data)
 		
 	}
 
-	if (girl->player_status == GIRL_PLAYER_TRUE) {
+	girl_player_backend_pause();
+	gtk_widget_destroy(girl->player_window);
 
+	if (girl->player_status == GIRL_PLAYER_TRUE) {
 		GIRL_DEBUG_MSG("Playback stopped.\n");
 		g_subprocess_force_exit(girl->player_subprocess);
 		// g_spawn_close_pid( girl->player_pid);
-		appbar_send_msg(_("Stopped playing the radio station %s in %s, exit the application GNOME Videos."),
+		appbar_send_msg(_("Stopped playing the radio station %s in %s."),
 				girl->selected_station_name,
 				girl->selected_station_location,
 				girl->selected_station_uri,
 				girl->selected_station_band);
-		girl->player_status = GIRL_PLAYER_FALSE;
 	}
 	/* if (girl->player_status != GIRL_RECORD_TRUE) { */
 	/* appbar_send_msg(_("Stop what?  You can \"Search\" by location, select a radio station from \"Stations\", or click on \"Listen\" and/or \"Record\".  Or go to \"Prev\" or \"Next\" radio station."), */
